==> org-lsst-ccs-subsystem-rafts-gui-1.10.5-sources.jar: org/lsst/ccs/subsystem/rafts/ui/jas/RaftsMonitorFilter.java <==
package org.lsst.ccs.subsystem.rafts.ui.jas;

import java.util.Collections;
import java.util.List;
import org.lsst.ccs.gconsole.agent.AgentChannel;
import org.lsst.ccs.gconsole.annotations.ConsoleLookup;
import org.lsst.ccs.gconsole.agent.filter.GenericFilter;
import org.lsst.ccs.gconsole.plugins.monitor.MonitorField;

/**
 * Rafts monitoring filter.
 *
 * @author The LSST CCS Team
 */
@ConsoleLookup(id="org.lsst.ccs.gconsole.agent.AgentChannelsFilter",
               name="Rafts monitor filter",
               path="Subsystems/Rafts/Monitor",
               description="Rafts subsystem monitor filter.")
public class RaftsMonitorFilter extends GenericFilter {


    public final static String FIELDS = 
        MonitorField.VALUE.getKey()+","+
        MonitorField.UNITS.getKey()+","+
        MonitorField.LOW_ALARM.getKey()+","+
        MonitorField.LOW_WARN.getKey()+","+
        MonitorField.ALERT_LOW.getKey()+","+
        MonitorField.HIGH_WARN.getKey()+","+
        MonitorField.HIGH_ALARM.getKey()+","+
        MonitorField.ALERT_HIGH.getKey()+","+
        MonitorField.NAME.getKey()+","+
        MonitorField.DESCR.getKey();
    
    public RaftsMonitorFilter(String agents) {
        super("Rafts",agents,"/main/", "", true, FIELDS);
    }

    
    
    @Override
    public List<String> getDisplayPath(AgentChannel channel) {
        String path = channel.getLocalPath();
        String section = channel.get(AgentChannel.Key.SECTION);
        //This is an ugly hack to account for the difference between
        //the raft and ts8 subsystems naming convention.
        if ( path.contains("R00.") ) {
            path = path.replace("R00.","");
        }        
        if ( section.contains("R00.") ) {
            section = section.replace("R00.","");
        }        
        
        int i1 = path.lastIndexOf("/");
        int i2 = path.indexOf(".", i1+1);
        String newPath = "";
        if (i1 != -1 && i2 != -1) {
            newPath = path.substring(i1 + 1, i2)+"//"+section+"//"+ path.substring(i2 + 1);
        } else {
            if ( i1 != -1 ) {
                newPath = section+"//"+path.substring(i1+1);
            } else if (i2 != -1) {
                newPath = section+"//"+path.substring(i2+1);                
            } else {
                newPath = section+"//"+path;
            }
        }        
        return Collections.singletonList(newPath);
    }

}

==> org-lsst-ccs-subsystem-rafts-gui-1.12.6-sources.jar: org/lsst/ccs/subsystem/rafts/ui/jas/RaftsMonitorFilter.java <==
package org.lsst.ccs.subsystem.rafts.ui.jas;

import org.lsst.ccs.gconsole.base.filter.GenericFilter;
import org.lsst.ccs.gconsole.plugins.monitor.MonitorField;
import org.lsst.ccs.gconsole.services.aggregator.AgentChannel;

/**
 * Rafts monitoring filter.
 *
 * @author The LSST CCS Team
 */
public class RaftsMonitorFilter extends GenericFilter {


    public final static String FIELDS = 
        MonitorField.VALUE.getKey()+","+
        MonitorField.UNITS.getKey()+","+
        MonitorField.LOW_ALARM.getKey()+","+
        MonitorField.LOW_WARN.getKey()+","+
        MonitorField.ALERT_LOW.getKey()+","+
        MonitorField.HIGH_WARN.getKey()+","+
        MonitorField.HIGH_ALARM.getKey()+","+
        MonitorField.ALERT_HIGH.getKey()+","+
        MonitorField.NAME.getKey()+","+
        MonitorField.DESCR.getKey();
    
    public RaftsMonitorFilter(String agents) {
        super("Rafts",agents,"/main/", "", true, FIELDS);
    }

    
    
    @Override
    public String getDisplayPath(AgentChannel channel) {
        String path = channel.getLocalPath();
        String section = channel.get(AgentChannel.Key.SECTION);
        //This is an ugly hack to account for the difference between
        //the raft and ts8 subsystems naming convention.
        if ( path.contains("R00.") ) {
            path = path.replace("R00.","");
        }        
        if ( section.contains("R00.") ) {
            section = section.replace("R00.","");
        }        
        
        int i1 = path.lastIndexOf("/");
        int i2 = path.indexOf(".", i1+1);
        String newPath = "";
        if (i1 != -1 && i2 != -1) {
            newPath = path.substring(i1 + 1, i2)+"//"+section+"//"+ path.substring(i2 + 1);
        } else {
            if ( i1 != -1 ) {
                newPath = section+"//"+path.substring(i1+1);
            } else if (i2 != -1) {
                newPath = section+"//"+path.substring(i2+1);                
            } else {
                newPath = section+"//"+path;
            }
        }        
        return newPath;
    }

}
